# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/1/22 18:26 
@Description     ： 常数项
'''


"""
增值税发票核验：https://cloud.tencent.com/document/product/1253/47678
CG还原角色：
AI还原声音：
"""

# 默认配置文件的位置
DEFAULT_CONFIG_PATH = r'./'
DEFAULT_CONFIG_NAME = 'poocr-config.toml'
DEFAULT_CONFIG_PATH_NAME = DEFAULT_CONFIG_PATH + DEFAULT_CONFIG_NAME
# 默认配置文件的使用教程
TUTORIA_VIDEO = 'https://www.bilibili.com/video/BV1Y3411R7q7'

NO_FILE_ERROR = '没有提供任何图片，请检查'

# 文字识别的参考文档
OCR_API_REF_DOC = 'https://cloud.tencent.com/document/product/866/33515'
# 默认的分行标志
SPLIT_LINE = '=' * 30
