from pocode.api.color import random_color_print

from poocr.api import ocr
from poocr.api import ocr2excel
from poocr.lib.Const import SPLIT_LINE

random_color_print(SPLIT_LINE)
random_color_print('【poocr库】，功能持续更新中')
random_color_print('使用有问题 or 提交你的功能需求 or 参与项目开发')
random_color_print('1、全部功能【视频 & 文字】教程：https://www.python-office.com/course-002/5-poocr/5-poocr.html')
random_color_print('2、请+【项目交流群】：http://www.python4office.cn/wechat-group/')
random_color_print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/poocr')
random_color_print('4、给小白的【50讲Python自动化办公】：https://www.python-office.com/course/50-python-office.html')
random_color_print(SPLIT_LINE)